# Vedro Telemetry

[![Codecov](https://img.shields.io/codecov/c/github/vedro-universe/vedro-telemetry/main.svg?style=flat-square)](https://codecov.io/gh/vedro-universe/vedro-telemetry)
[![PyPI](https://img.shields.io/pypi/v/vedro-telemetry.svg?style=flat-square)](https://pypi.org/project/vedro-telemetry/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/vedro-telemetry?style=flat-square)](https://pypi.org/project/vedro-telemetry/)
[![Python Version](https://img.shields.io/pypi/pyversions/vedro-telemetry.svg?style=flat-square)](https://pypi.org/project/vedro-telemetry/)

[vedro-telemetry](https://pypi.org/project/vedro-telemetry/) is an external Vedro plugin that enables saving telemetry events to your own **self-hosted** server. It's useful for teams to monitor and analyze their test suites across different projects in a centralized manner.

## Documentation

For installation instructions, usage details, and more information, please refer to the [documentation](https://vedro.io/docs/solutions/self-hosted-telemetry).
